==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkVolumeProperty.java <==
// java wrapper for vtkVolumeProperty object
//

package vtk;
import vtk.*;

public class vtkVolumeProperty extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void DeepCopy_2(vtkVolumeProperty id0);
  public void DeepCopy(vtkVolumeProperty id0)
    { DeepCopy_2(id0); }

  private native int GetMTime_3();
  public int GetMTime()
    { return GetMTime_3(); }

  private native void SetIndependentComponents_4(int id0);
  public void SetIndependentComponents(int id0)
    { SetIndependentComponents_4(id0); }

  private native int GetIndependentComponentsMinValue_5();
  public int GetIndependentComponentsMinValue()
    { return GetIndependentComponentsMinValue_5(); }

  private native int GetIndependentComponentsMaxValue_6();
  public int GetIndependentComponentsMaxValue()
    { return GetIndependentComponentsMaxValue_6(); }

  private native int GetIndependentComponents_7();
  public int GetIndependentComponents()
    { return GetIndependentComponents_7(); }

  private native void IndependentComponentsOn_8();
  public void IndependentComponentsOn()
    { IndependentComponentsOn_8(); }

  private native void IndependentComponentsOff_9();
  public void IndependentComponentsOff()
    { IndependentComponentsOff_9(); }

  private native void SetInterpolationType_10(int id0);
  public void SetInterpolationType(int id0)
    { SetInterpolationType_10(id0); }

  private native int GetInterpolationTypeMinValue_11();
  public int GetInterpolationTypeMinValue()
    { return GetInterpolationTypeMinValue_11(); }

  private native int GetInterpolationTypeMaxValue_12();
  public int GetInterpolationTypeMaxValue()
    { return GetInterpolationTypeMaxValue_12(); }

  private native int GetInterpolationType_13();
  public int GetInterpolationType()
    { return GetInterpolationType_13(); }

  private native void SetInterpolationTypeToNearest_14();
  public void SetInterpolationTypeToNearest()
    { SetInterpolationTypeToNearest_14(); }

  private native void SetInterpolationTypeToLinear_15();
  public void SetInterpolationTypeToLinear()
    { SetInterpolationTypeToLinear_15(); }

  private native String GetInterpolationTypeAsString_16();
  public String GetInterpolationTypeAsString()
    { return GetInterpolationTypeAsString_16(); }

  private native void SetComponentWeight_17(int id0,double id1);
  public void SetComponentWeight(int id0,double id1)
    { SetComponentWeight_17(id0,id1); }

  private native double GetComponentWeight_18(int id0);
  public double GetComponentWeight(int id0)
    { return GetComponentWeight_18(id0); }

  private native void SetColor_19(int id0,vtkPiecewiseFunction id1);
  public void SetColor(int id0,vtkPiecewiseFunction id1)
    { SetColor_19(id0,id1); }

  private native void SetColor_20(vtkPiecewiseFunction id0);
  public void SetColor(vtkPiecewiseFunction id0)
    { SetColor_20(id0); }

  private native void SetColor_21(int id0,vtkColorTransferFunction id1);
  public void SetColor(int id0,vtkColorTransferFunction id1)
    { SetColor_21(id0,id1); }

  private native void SetColor_22(vtkColorTransferFunction id0);
  public void SetColor(vtkColorTransferFunction id0)
    { SetColor_22(id0); }

  private native int GetColorChannels_23(int id0);
  public int GetColorChannels(int id0)
    { return GetColorChannels_23(id0); }

  private native int GetColorChannels_24();
  public int GetColorChannels()
    { return GetColorChannels_24(); }

  private native long GetGrayTransferFunction_25(int id0);
  public vtkPiecewiseFunction GetGrayTransferFunction(int id0) {
    long temp = GetGrayTransferFunction_25(id0);

    if (temp == 0) return null;
    return (vtkPiecewiseFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetGrayTransferFunction_26();
  public vtkPiecewiseFunction GetGrayTransferFunction() {
    long temp = GetGrayTransferFunction_26();

    if (temp == 0) return null;
    return (vtkPiecewiseFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetRGBTransferFunction_27(int id0);
  public vtkColorTransferFunction GetRGBTransferFunction(int id0) {
    long temp = GetRGBTransferFunction_27(id0);

    if (temp == 0) return null;
    return (vtkColorTransferFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetRGBTransferFunction_28();
  public vtkColorTransferFunction GetRGBTransferFunction() {
    long temp = GetRGBTransferFunction_28();

    if (temp == 0) return null;
    return (vtkColorTransferFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScalarOpacity_29(int id0,vtkPiecewiseFunction id1);
  public void SetScalarOpacity(int id0,vtkPiecewiseFunction id1)
    { SetScalarOpacity_29(id0,id1); }

  private native void SetScalarOpacity_30(vtkPiecewiseFunction id0);
  public void SetScalarOpacity(vtkPiecewiseFunction id0)
    { SetScalarOpacity_30(id0); }

  private native long GetScalarOpacity_31(int id0);
  public vtkPiecewiseFunction GetScalarOpacity(int id0) {
    long temp = GetScalarOpacity_31(id0);

    if (temp == 0) return null;
    return (vtkPiecewiseFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetScalarOpacity_32();
  public vtkPiecewiseFunction GetScalarOpacity() {
    long temp = GetScalarOpacity_32();

    if (temp == 0) return null;
    return (vtkPiecewiseFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScalarOpacityUnitDistance_33(int id0,double id1);
  public void SetScalarOpacityUnitDistance(int id0,double id1)
    { SetScalarOpacityUnitDistance_33(id0,id1); }

  private native void SetScalarOpacityUnitDistance_34(double id0);
  public void SetScalarOpacityUnitDistance(double id0)
    { SetScalarOpacityUnitDistance_34(id0); }

  private native double GetScalarOpacityUnitDistance_35(int id0);
  public double GetScalarOpacityUnitDistance(int id0)
    { return GetScalarOpacityUnitDistance_35(id0); }

  private native double GetScalarOpacityUnitDistance_36();
  public double GetScalarOpacityUnitDistance()
    { return GetScalarOpacityUnitDistance_36(); }

  private native void SetGradientOpacity_37(int id0,vtkPiecewiseFunction id1);
  public void SetGradientOpacity(int id0,vtkPiecewiseFunction id1)
    { SetGradientOpacity_37(id0,id1); }

  private native void SetGradientOpacity_38(vtkPiecewiseFunction id0);
  public void SetGradientOpacity(vtkPiecewiseFunction id0)
    { SetGradientOpacity_38(id0); }

  private native long GetGradientOpacity_39(int id0);
  public vtkPiecewiseFunction GetGradientOpacity(int id0) {
    long temp = GetGradientOpacity_39(id0);

    if (temp == 0) return null;
    return (vtkPiecewiseFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetGradientOpacity_40();
  public vtkPiecewiseFunction GetGradientOpacity() {
    long temp = GetGradientOpacity_40();

    if (temp == 0) return null;
    return (vtkPiecewiseFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetDisableGradientOpacity_41(int id0,int id1);
  public void SetDisableGradientOpacity(int id0,int id1)
    { SetDisableGradientOpacity_41(id0,id1); }

  private native void SetDisableGradientOpacity_42(int id0);
  public void SetDisableGradientOpacity(int id0)
    { SetDisableGradientOpacity_42(id0); }

  private native void DisableGradientOpacityOn_43(int id0);
  public void DisableGradientOpacityOn(int id0)
    { DisableGradientOpacityOn_43(id0); }

  private native void DisableGradientOpacityOn_44();
  public void DisableGradientOpacityOn()
    { DisableGradientOpacityOn_44(); }

  private native void DisableGradientOpacityOff_45(int id0);
  public void DisableGradientOpacityOff(int id0)
    { DisableGradientOpacityOff_45(id0); }

  private native void DisableGradientOpacityOff_46();
  public void DisableGradientOpacityOff()
    { DisableGradientOpacityOff_46(); }

  private native int GetDisableGradientOpacity_47(int id0);
  public int GetDisableGradientOpacity(int id0)
    { return GetDisableGradientOpacity_47(id0); }

  private native int GetDisableGradientOpacity_48();
  public int GetDisableGradientOpacity()
    { return GetDisableGradientOpacity_48(); }

  private native long GetStoredGradientOpacity_49(int id0);
  public vtkPiecewiseFunction GetStoredGradientOpacity(int id0) {
    long temp = GetStoredGradientOpacity_49(id0);

    if (temp == 0) return null;
    return (vtkPiecewiseFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStoredGradientOpacity_50();
  public vtkPiecewiseFunction GetStoredGradientOpacity() {
    long temp = GetStoredGradientOpacity_50();

    if (temp == 0) return null;
    return (vtkPiecewiseFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native boolean HasGradientOpacity_51(int id0);
  public boolean HasGradientOpacity(int id0)
    { return HasGradientOpacity_51(id0); }

  private native void SetShade_52(int id0,int id1);
  public void SetShade(int id0,int id1)
    { SetShade_52(id0,id1); }

  private native void SetShade_53(int id0);
  public void SetShade(int id0)
    { SetShade_53(id0); }

  private native int GetShade_54(int id0);
  public int GetShade(int id0)
    { return GetShade_54(id0); }

  private native int GetShade_55();
  public int GetShade()
    { return GetShade_55(); }

  private native void ShadeOn_56(int id0);
  public void ShadeOn(int id0)
    { ShadeOn_56(id0); }

  private native void ShadeOn_57();
  public void ShadeOn()
    { ShadeOn_57(); }

  private native void ShadeOff_58(int id0);
  public void ShadeOff(int id0)
    { ShadeOff_58(id0); }

  private native void ShadeOff_59();
  public void ShadeOff()
    { ShadeOff_59(); }

  private native void SetAmbient_60(int id0,double id1);
  public void SetAmbient(int id0,double id1)
    { SetAmbient_60(id0,id1); }

  private native void SetAmbient_61(double id0);
  public void SetAmbient(double id0)
    { SetAmbient_61(id0); }

  private native double GetAmbient_62(int id0);
  public double GetAmbient(int id0)
    { return GetAmbient_62(id0); }

  private native double GetAmbient_63();
  public double GetAmbient()
    { return GetAmbient_63(); }

  private native void SetDiffuse_64(int id0,double id1);
  public void SetDiffuse(int id0,double id1)
    { SetDiffuse_64(id0,id1); }

  private native void SetDiffuse_65(double id0);
  public void SetDiffuse(double id0)
    { SetDiffuse_65(id0); }

  private native double GetDiffuse_66(int id0);
  public double GetDiffuse(int id0)
    { return GetDiffuse_66(id0); }

  private native double GetDiffuse_67();
  public double GetDiffuse()
    { return GetDiffuse_67(); }

  private native void SetSpecular_68(int id0,double id1);
  public void SetSpecular(int id0,double id1)
    { SetSpecular_68(id0,id1); }

  private native void SetSpecular_69(double id0);
  public void SetSpecular(double id0)
    { SetSpecular_69(id0); }

  private native double GetSpecular_70(int id0);
  public double GetSpecular(int id0)
    { return GetSpecular_70(id0); }

  private native double GetSpecular_71();
  public double GetSpecular()
    { return GetSpecular_71(); }

  private native void SetSpecularPower_72(int id0,double id1);
  public void SetSpecularPower(int id0,double id1)
    { SetSpecularPower_72(id0,id1); }

  private native void SetSpecularPower_73(double id0);
  public void SetSpecularPower(double id0)
    { SetSpecularPower_73(id0); }

  private native double GetSpecularPower_74(int id0);
  public double GetSpecularPower(int id0)
    { return GetSpecularPower_74(id0); }

  private native double GetSpecularPower_75();
  public double GetSpecularPower()
    { return GetSpecularPower_75(); }

  private native void UpdateMTimes_76();
  public void UpdateMTimes()
    { UpdateMTimes_76(); }

  public vtkVolumeProperty() { super(); }

  public vtkVolumeProperty(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkVolumeProperty.java <==
// java wrapper for vtkVolumeProperty object
//

package vtk;
import vtk.*;

public class vtkVolumeProperty extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void DeepCopy_2(vtkVolumeProperty id0);
  public void DeepCopy(vtkVolumeProperty id0)
    { DeepCopy_2(id0); }

  private native int GetMTime_3();
  public int GetMTime()
    { return GetMTime_3(); }

  private native void SetIndependentComponents_4(int id0);
  public void SetIndependentComponents(int id0)
    { SetIndependentComponents_4(id0); }

  private native int GetIndependentComponentsMinValue_5();
  public int GetIndependentComponentsMinValue()
    { return GetIndependentComponentsMinValue_5(); }

  private native int GetIndependentComponentsMaxValue_6();
  public int GetIndependentComponentsMaxValue()
    { return GetIndependentComponentsMaxValue_6(); }

  private native int GetIndependentComponents_7();
  public int GetIndependentComponents()
    { return GetIndependentComponents_7(); }

  private native void IndependentComponentsOn_8();
  public void IndependentComponentsOn()
    { IndependentComponentsOn_8(); }

  private native void IndependentComponentsOff_9();
  public void IndependentComponentsOff()
    { IndependentComponentsOff_9(); }

  private native void SetInterpolationType_10(int id0);
  public void SetInterpolationType(int id0)
    { SetInterpolationType_10(id0); }

  private native int GetInterpolationTypeMinValue_11();
  public int GetInterpolationTypeMinValue()
    { return GetInterpolationTypeMinValue_11(); }

  private native int GetInterpolationTypeMaxValue_12();
  public int GetInterpolationTypeMaxValue()
    { return GetInterpolationTypeMaxValue_12(); }

  private native int GetInterpolationType_13();
  public int GetInterpolationType()
    { return GetInterpolationType_13(); }

  private native void SetInterpolationTypeToNearest_14();
  public void SetInterpolationTypeToNearest()
    { SetInterpolationTypeToNearest_14(); }

  private native void SetInterpolationTypeToLinear_15();
  public void SetInterpolationTypeToLinear()
    { SetInterpolationTypeToLinear_15(); }

  private native String GetInterpolationTypeAsString_16();
  public String GetInterpolationTypeAsString()
    { return GetInterpolationTypeAsString_16(); }

  private native void SetComponentWeight_17(int id0,double id1);
  public void SetComponentWeight(int id0,double id1)
    { SetComponentWeight_17(id0,id1); }

  private native double GetComponentWeight_18(int id0);
  public double GetComponentWeight(int id0)
    { return GetComponentWeight_18(id0); }

  private native void SetColor_19(int id0,vtkPiecewiseFunction id1);
  public void SetColor(int id0,vtkPiecewiseFunction id1)
    { SetColor_19(id0,id1); }

  private native void SetColor_20(vtkPiecewiseFunction id0);
  public void SetColor(vtkPiecewiseFunction id0)
    { SetColor_20(id0); }

  private native void SetColor_21(int id0,vtkColorTransferFunction id1);
  public void SetColor(int id0,vtkColorTransferFunction id1)
    { SetColor_21(id0,id1); }

  private native void SetColor_22(vtkColorTransferFunction id0);
  public void SetColor(vtkColorTransferFunction id0)
    { SetColor_22(id0); }

  private native int GetColorChannels_23(int id0);
  public int GetColorChannels(int id0)
    { return GetColorChannels_23(id0); }

  private native int GetColorChannels_24();
  public int GetColorChannels()
    { return GetColorChannels_24(); }

  private native long GetGrayTransferFunction_25(int id0);
  public vtkPiecewiseFunction GetGrayTransferFunction(int id0) {
    long temp = GetGrayTransferFunction_25(id0);

    if (temp == 0) return null;
    return (vtkPiecewiseFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetGrayTransferFunction_26();
  public vtkPiecewiseFunction GetGrayTransferFunction() {
    long temp = GetGrayTransferFunction_26();

    if (temp == 0) return null;
    return (vtkPiecewiseFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetRGBTransferFunction_27(int id0);
  public vtkColorTransferFunction GetRGBTransferFunction(int id0) {
    long temp = GetRGBTransferFunction_27(id0);

    if (temp == 0) return null;
    return (vtkColorTransferFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetRGBTransferFunction_28();
  public vtkColorTransferFunction GetRGBTransferFunction() {
    long temp = GetRGBTransferFunction_28();

    if (temp == 0) return null;
    return (vtkColorTransferFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScalarOpacity_29(int id0,vtkPiecewiseFunction id1);
  public void SetScalarOpacity(int id0,vtkPiecewiseFunction id1)
    { SetScalarOpacity_29(id0,id1); }

  private native void SetScalarOpacity_30(vtkPiecewiseFunction id0);
  public void SetScalarOpacity(vtkPiecewiseFunction id0)
    { SetScalarOpacity_30(id0); }

  private native long GetScalarOpacity_31(int id0);
  public vtkPiecewiseFunction GetScalarOpacity(int id0) {
    long temp = GetScalarOpacity_31(id0);

    if (temp == 0) return null;
    return (vtkPiecewiseFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetScalarOpacity_32();
  public vtkPiecewiseFunction GetScalarOpacity() {
    long temp = GetScalarOpacity_32();

    if (temp == 0) return null;
    return (vtkPiecewiseFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScalarOpacityUnitDistance_33(int id0,double id1);
  public void SetScalarOpacityUnitDistance(int id0,double id1)
    { SetScalarOpacityUnitDistance_33(id0,id1); }

  private native void SetScalarOpacityUnitDistance_34(double id0);
  public void SetScalarOpacityUnitDistance(double id0)
    { SetScalarOpacityUnitDistance_34(id0); }

  private native double GetScalarOpacityUnitDistance_35(int id0);
  public double GetScalarOpacityUnitDistance(int id0)
    { return GetScalarOpacityUnitDistance_35(id0); }

  private native double GetScalarOpacityUnitDistance_36();
  public double GetScalarOpacityUnitDistance()
    { return GetScalarOpacityUnitDistance_36(); }

  private native void SetGradientOpacity_37(int id0,vtkPiecewiseFunction id1);
  public void SetGradientOpacity(int id0,vtkPiecewiseFunction id1)
    { SetGradientOpacity_37(id0,id1); }

  private native void SetGradientOpacity_38(vtkPiecewiseFunction id0);
  public void SetGradientOpacity(vtkPiecewiseFunction id0)
    { SetGradientOpacity_38(id0); }

  private native long GetGradientOpacity_39(int id0);
  public vtkPiecewiseFunction GetGradientOpacity(int id0) {
    long temp = GetGradientOpacity_39(id0);

    if (temp == 0) return null;
    return (vtkPiecewiseFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetGradientOpacity_40();
  public vtkPiecewiseFunction GetGradientOpacity() {
    long temp = GetGradientOpacity_40();

    if (temp == 0) return null;
    return (vtkPiecewiseFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetDisableGradientOpacity_41(int id0,int id1);
  public void SetDisableGradientOpacity(int id0,int id1)
    { SetDisableGradientOpacity_41(id0,id1); }

  private native void SetDisableGradientOpacity_42(int id0);
  public void SetDisableGradientOpacity(int id0)
    { SetDisableGradientOpacity_42(id0); }

  private native void DisableGradientOpacityOn_43(int id0);
  public void DisableGradientOpacityOn(int id0)
    { DisableGradientOpacityOn_43(id0); }

  private native void DisableGradientOpacityOn_44();
  public void DisableGradientOpacityOn()
    { DisableGradientOpacityOn_44(); }

  private native void DisableGradientOpacityOff_45(int id0);
  public void DisableGradientOpacityOff(int id0)
    { DisableGradientOpacityOff_45(id0); }

  private native void DisableGradientOpacityOff_46();
  public void DisableGradientOpacityOff()
    { DisableGradientOpacityOff_46(); }

  private native int GetDisableGradientOpacity_47(int id0);
  public int GetDisableGradientOpacity(int id0)
    { return GetDisableGradientOpacity_47(id0); }

  private native int GetDisableGradientOpacity_48();
  public int GetDisableGradientOpacity()
    { return GetDisableGradientOpacity_48(); }

  private native long GetStoredGradientOpacity_49(int id0);
  public vtkPiecewiseFunction GetStoredGradientOpacity(int id0) {
    long temp = GetStoredGradientOpacity_49(id0);

    if (temp == 0) return null;
    return (vtkPiecewiseFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStoredGradientOpacity_50();
  public vtkPiecewiseFunction GetStoredGradientOpacity() {
    long temp = GetStoredGradientOpacity_50();

    if (temp == 0) return null;
    return (vtkPiecewiseFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native boolean HasGradientOpacity_51(int id0);
  public boolean HasGradientOpacity(int id0)
    { return HasGradientOpacity_51(id0); }

  private native void SetShade_52(int id0,int id1);
  public void SetShade(int id0,int id1)
    { SetShade_52(id0,id1); }

  private native void SetShade_53(int id0);
  public void SetShade(int id0)
    { SetShade_53(id0); }

  private native int GetShade_54(int id0);
  public int GetShade(int id0)
    { return GetShade_54(id0); }

  private native int GetShade_55();
  public int GetShade()
    { return GetShade_55(); }

  private native void ShadeOn_56(int id0);
  public void ShadeOn(int id0)
    { ShadeOn_56(id0); }

  private native void ShadeOn_57();
  public void ShadeOn()
    { ShadeOn_57(); }

  private native void ShadeOff_58(int id0);
  public void ShadeOff(int id0)
    { ShadeOff_58(id0); }

  private native void ShadeOff_59();
  public void ShadeOff()
    { ShadeOff_59(); }

  private native void SetAmbient_60(int id0,double id1);
  public void SetAmbient(int id0,double id1)
    { SetAmbient_60(id0,id1); }

  private native void SetAmbient_61(double id0);
  public void SetAmbient(double id0)
    { SetAmbient_61(id0); }

  private native double GetAmbient_62(int id0);
  public double GetAmbient(int id0)
    { return GetAmbient_62(id0); }

  private native double GetAmbient_63();
  public double GetAmbient()
    { return GetAmbient_63(); }

  private native void SetDiffuse_64(int id0,double id1);
  public void SetDiffuse(int id0,double id1)
    { SetDiffuse_64(id0,id1); }

  private native void SetDiffuse_65(double id0);
  public void SetDiffuse(double id0)
    { SetDiffuse_65(id0); }

  private native double GetDiffuse_66(int id0);
  public double GetDiffuse(int id0)
    { return GetDiffuse_66(id0); }

  private native double GetDiffuse_67();
  public double GetDiffuse()
    { return GetDiffuse_67(); }

  private native void SetSpecular_68(int id0,double id1);
  public void SetSpecular(int id0,double id1)
    { SetSpecular_68(id0,id1); }

  private native void SetSpecular_69(double id0);
  public void SetSpecular(double id0)
    { SetSpecular_69(id0); }

  private native double GetSpecular_70(int id0);
  public double GetSpecular(int id0)
    { return GetSpecular_70(id0); }

  private native double GetSpecular_71();
  public double GetSpecular()
    { return GetSpecular_71(); }

  private native void SetSpecularPower_72(int id0,double id1);
  public void SetSpecularPower(int id0,double id1)
    { SetSpecularPower_72(id0,id1); }

  private native void SetSpecularPower_73(double id0);
  public void SetSpecularPower(double id0)
    { SetSpecularPower_73(id0); }

  private native double GetSpecularPower_74(int id0);
  public double GetSpecularPower(int id0)
    { return GetSpecularPower_74(id0); }

  private native double GetSpecularPower_75();
  public double GetSpecularPower()
    { return GetSpecularPower_75(); }

  private native void UpdateMTimes_76();
  public void UpdateMTimes()
    { UpdateMTimes_76(); }

  public vtkVolumeProperty() { super(); }

  public vtkVolumeProperty(long id) { super(id); }
  public native long   VTKInit();

}
